==> qmmp-plugin-pack_1.3.1.orig.tar.xz: src/Effect/srconverter/translations/srconverter_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation>Greffon de conversion d&apos;échantillonnage</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>À propos du greffon de conversion d&apos;échantillonnage</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Greffon de conversion d&apos;échantillonnage pour Qmmp</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Configuration du greffon de conversion d&apos;échantillonnage</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation>Taux d&apos;échantillonnage (Hz) :</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation>Moteur d&apos;interpolation :</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation>interpolation sinc la meilleure</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation>interpolation sinc moyenne</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>interpolation sinc la plus rapide</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation>interpolation ZOH</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation>interpolation linéaire</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack_1.6.1.orig.tar.xz: src/Effect/srconverter/translations/srconverter_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation>Greffon de conversion d&apos;échantillonnage</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>À propos du greffon de conversion d&apos;échantillonnage</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Greffon de conversion d&apos;échantillonnage pour Qmmp</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Configuration du greffon de conversion d&apos;échantillonnage</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation>Taux d&apos;échantillonnage (Hz)&#xa0;:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation>Moteur d&apos;interpolation&#xa0;:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation>interpolation sinc la meilleure</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation>interpolation sinc moyenne</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>interpolation sinc la plus rapide</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation>interpolation ZOH</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation>interpolation linéaire</translation>
    </message>
</context>
</TS>
